@@ -24,19 +24,7 @@
 # @keyword internal
 #*/###########################################################################
 setMethodS3("trim", "default", function(object, ...) {
-  s <- sub("^[\t\n\f\r ]*", "", as.character(object));
-  s <- sub("[\t\n\f\r ]*$", "", s);
-  s;
+  s <- sub("^[\t\n\f\r ]*", "", as.character(object))
+  s <- sub("[\t\n\f\r ]*$", "", s)
+  s
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2005-02-15
-# o Added arguments '...' in order to match any generic functions.
-# 2004-10-18
-# o Added Rdoc comments.
-# 2002-12-08
-# o Currently used by the Rdoc class.
-############################################################################
